#!/usr/bin/env python
#-*-coding: utf-8 -*-
"""

a tool for finding your files across different machines!

not pretty.. full of quick-and-dirty hacks .. but works :-)

"""
__author__ = "Marcin Magnus"
__copyright__ = "Copyright 2010, Marcin Magnus"
__license__ = "GPL"
__maintainer__ = "Marcin Magnus"
__email__ = "mag_dex@o2.pl"
__status__ = "Development"
__version__ = '0.98 alpha'

from sys import exit, argv
from string import ascii_letters
from os import path, getcwd, system, sep
from subprocess import Popen
from commands import getoutput
from re import compile, search, I
from time import sleep
from optparse import OptionParser
from getpass import getuser

import getpass


from mmfinder_deamon import start as start_deamon

from lib.utils import banner2, hr, get_hostname, hr_text, print_red_and_blue, check_user_configuration
from mmfinder_config import PLACES_LOCAL, PLACES_GLOBAL,\
PATH_DB, FF_SQLITE_DATABASE,\
EXTENSIONS_OF_DOCUMENTS, EXTENSIONS_OF_MEDIA, HTML_FN, HTML_CMD, GREP_CMD

IDS = ascii_letters


class App:
    """
    Class for the main app
    """
    def __init__(self):
        """
        Inits the main app.
        """
        self.items = []

    def search(self, arguments, opt):
        """
        This searches :-)

        This function is way too big and should be split up
        (it has 267 lines and up to 45 local variables!)

        * input:

        - arguments & opt based on cmd input by user
        """
        list_with_action = True

        hr()

        # if x 2 related to firefox's bookmarks
        if opt.bookmarks:
            # sqlite3 is required!
            import sqlite3
            conn = sqlite3.connect(FF_SQLITE_DATABASE)
            c = conn.cursor()
            c.execute("select title, url from moz_places;")
            conn.commit()
            results = c.fetchall()
            if 1:
                for r in results:
                    title = r[0]
                    if title:
                        pass
                    else:
                        title = ''
                    line = title + r[1]

                    # a stupid way
                    word = arguments[0]
                    try:
                        word2 = arguments[1]
                    except IndexError:
                        word2 = ''

                    if compile(word, I).search(line) \
                        and compile(word2, I).search(line):
                        print_red_and_blue(title, ' ' + r[1])
                exit(1)

        if opt.bookmarks_folder:
            # dirty but works
            # django required!
            try:
                from django.conf import settings
            except ImportError:
                print 'ImportError: Install python-django to run this feature: sudo apt-get install python-django or sudo pip install django'
                exit(1)
                
            DATABASES = {
                'default': {
                    'ENGINE': 'django.db.backends.sqlite3',
                    'NAME':  FF_SQLITE_DATABASE,
                    'HOST': '',
                    'PORT': '',
                    }
                }
            settings.configure(DATABASES=DATABASES)

            from orm.models import MozBookmarks

            show_path = False

            phrase = argv[2].strip()

            print 'phrase:', phrase, '\n'

            bookmarks = MozBookmarks.objects.all()

            c = 0
            for b in bookmarks:
                if b.fk is None and b.title != '':  # b.fk = has bookmarks
                    try:
                        path = b.title.strip()
                    except AttributeError:
                        print '-- b.title:', b.title
                    while b.parent != 1:
                        parent = MozBookmarks.objects.get(id=b.parent)
                        path = parent.title.strip() + '/' + path
                        b = parent
                    if show_path:
                        print path
                    if path.lower().find(phrase.lower()) > -1:
                        print path
                c += 1
            exit(1)

        if opt.invert:
            arguments.reverse()

        # main search body
        words = '*' + '*'.join(arguments) + '*'  # '*a*b*c*'
        words_rex = '.*' + '.*'.join(arguments) + '.*'  # '.*a.*b*.c*'

        if opt.global_search:
            places = PLACES_GLOBAL
        else:
            places = PLACES_LOCAL
            places.append(get_hostname())

        if opt.grep_here:
            places = ['current dir']
            status = 'grepping the current directory'
            cmd = GREP_CMD + " '" + words.replace('*', '') + "' *"
            if opt.verbose:
                print 'cmd: ', cmd
            out = getoutput(cmd).strip()
            for l in out.split('\n'):
                if l.find(':') > -1:
                    try:
                        filename, text = l.split(':')
                        filename += ':'
                    except:
                        items = l.split(':')
                        filename = items[0]
                        text = ':'.join(items[1:])
                    print_red_and_blue(filename, text)

                elif l.find('-') > -1:
                    try:
                        filename, text = l.split('-')
                        filename += '-'
                    except:
                        items = l.split('-')
                        filename = items[0]
                        text = '-'.join(items[1:])
                    print_red_and_blue(filename, text)
                else:
                    print l
            exit(1)

        if opt.wholename:  # or basename
            wholename_or_basename = ' -w '
        else:
            wholename_or_basename = ' -b '

        if opt.find_dir:
            places = ['find directories@' + get_hostname()]
        if opt.find_find:
            places = ['find@' + get_hostname()]
        if opt.find_tu:
            places = ['find here -t tu@' + get_hostname()]

        # reset file
        paths_text_file = open('/home/' + getuser() + '/.mmfinder-paths', 'w')
        paths_text_file_to_open = open('/home/' +
                                        getuser() +
                                        '/.mmfinder-paths-to-open', 'w')

        mmterminalpathtext = ''
        mmterminalpathtext_to_open = ''

        html_hits = ''
        c = 1
        for p in places:
            hr_text(p + '...')
            html_hits += '#' + p + '\n'

            status = ''

            if opt.pdf_find:
                status = 'pdf searching...'
                cmd = "locate -d " + PATH_DB + p + '.db' + " " + \
                    wholename_or_basename + " -i -r '" + words_rex + "pdf"

            elif opt.document_find:
                status = 'document searching...'
                extensions = '$|'.join(EXTENSIONS_OF_DOCUMENTS)
                cmd = "locate -d " + PATH_DB + p + '.db' + " " + \
                    wholename_or_basename + " -i --regex '" + \
                    words_rex + ".*(" + extensions + ")'"

            elif opt.find_media:
                status = 'document searching...'
                extensions = '$|'.join(EXTENSIONS_OF_MEDIA)
                cmd = "locate -d " + PATH_DB + p + '.db' + " " + \
                    wholename_or_basename + " -i --regex '" + \
                    words_rex + ".*(" + extensions + ")'"

            elif opt.rex:
                status = 'rex searching...'
                word = arguments[0]  # <--- !!!
                cmd = "locate -d " + PATH_DB + p + '.db' + " " + \
                    wholename_or_basename + " -i --regex '" + word + "'"

            elif opt.find_tu:
                status = 'finding here (tutaj)...'
                cmd = "find '" + getcwd() + "' -iname '" + words + "'"

            elif opt.find_find:
                status = 'finding /home/...'
                cmd = "find ~ -iname '" + words + "'"

            elif opt.find_dir:
                status = 'finding a dir /...'
                cmd = "find ~ -iname '" + words + "' -type d"  # very slow :-(

                if False:
                    if word.startswith('^'):
                        word_without = word.replace('^', '')
                        cmd = "locate -d " + PATH_DB + p + '.db' + \
                            " -e -i -r  '/" + word_without + \
                            "*' | xarguments file"
                            #locate -r '/*python2.7*/' | less
                    else:
                        cmd = "locate -d " + PATH_DB + p + '.db' + \
                            " -e -i -r  '/*" + word + "*/'" \
                            #locate -r '/*python2.7*/' | less
            else:

                status = 'basic search...'
                cmd = "locate -d " + PATH_DB + p + '.db' + \
                    " " + wholename_or_basename + " -i '" + words + "'"

            if opt.un_grep:
                cmd = cmd + " | grep -v '" + opt.un_grep + "'"

            if opt.verbose:
                print '# status:', status
                print '# cmd', cmd

            # execute!
            out = getoutput(cmd).strip()

            if opt.dev:
                hr_text('dev::out')
                print out
                hr()

            if out and list_with_action:
                for item in out.strip().split('\n'):
                    # @@ BUG @@ id = IDS[c]
                    id = 'a'  # TO FIX
                    h = Hit(id, item)
                    self.items.append(h)
                    h.check_filetype()
                    #print i.is_dir
                    #if i.is_dir and find_dir:
                    #    i.show()
                    #print 'x'
                    #if not find_dir:
                    hit = h.show(opt.not_less,
                                 opt.noncolor, c)
                    if opt.www_browser:
                        html_hits += hit + '\n'
                    else:
                        mmterminalpathtext += hit.split('\n')[0].strip() \
                        + ' #' + str(c) + '\n'
                        mmterminalpathtext_to_open += hit.split('\n')[1].strip() \
                        + ' #' + str(c) + '\n'
                    c += 1
                print

            # and out becuase don't 'press key' for empty outputs
            if opt.key and out:
                raw_input('[press key]')

        if opt.www_browser:
            html_text = '<pre>'
            html_text += html_hits.replace('\n', '</br>')
            html_text += '<pre>'

            fn = HTML_FN
            f = open(fn, 'w')
            f.write(html_text)
            f.close()

            cmd = HTML_CMD + ' ' + fn
            print cmd
            system(cmd)

        paths_text_file.write(mmterminalpathtext)
        paths_text_file_to_open.write(mmterminalpathtext_to_open)
        paths_text_file.close()


class Hit:
    """
    Class for a hit of search.
    """
    def __init__(self, id, path):
        self.path = path
        self.id = id
        self.filetype = ''
        self.is_pdf = False
        self.is_empty = False

    def show(self, not_less, noncolor, c):
        """
        Shows (print/save to html) one hit.

        * input:

         - show_hash **is not used**
         - less: True/False show only first line of a hit, dont show path file:///
         - noncolor: True/False use color to show a path and a filename
         - www_browser: save the result as a html file and open it in www_browser

        * output:

        - '\tfile:///home/magnus/Dropbox/pdf\n\tfile:///home/magnus/Dropbox/pdf/XXXXXXX.pdf'
           or
           html code for opening in www_browser
        """
        #if not self.is_empty:
            # out = '\t [' + self.filetype + '] ' + self.id + ") \
                # file://"+self.path.replace(' ','\ ')+""
            #out = '\t [' + self.filetype + '] ' + self.id + ") \
                # file://"+self.path.replace(' ','%20')+""
        if noncolor:
            print '\t\'' + path.dirname(self.path) + \
                  '/' + path.basename(self.path) + "'"
        else:
            print_red_and_blue(str(c) + '\t\'' +
                               path.dirname(self.path) +
                               '/', '' + path.basename(self.path) + "'")
        # hack #1
        out = ''
        dir_file = True
        if dir_file:
            out = "\tfile://" + \
                path.dirname(self.path).strip().replace(' ', '%20') + "\n"
                #out = '\t [' + self.filetype + '] ' + \
                #self.id + ") " + '' + " \t\tfile://"+
                #self.path.replace(' ','%20')+""
        out += "\tfile://" + self.path.replace(' ', '%20') + ""
            # @todo
            #if show_hash:
            #    out += '\n\t' + hash_file(self.path)[0]

            #out = '\t [' + self.filetype + '] ' + self.id + ") \
                # file:'//"+self.path+"'" # NO
            #out = '\t [' + self.filetype + '] ' + self.id + ") \
            # 'file://"+self.path+"'" # NO
        if not_less:
            print out
        return out.replace('file://', '').replace('%20', ' ')

    def check_filetype(self, verbose=False):
        """
        Checks filetype of a hit.
        """
        if not path.isfile(self.path):
            self.is_dir = True
            self.filetype = 'dir'
        else:
            self.is_dir = False

            cmd = "file '" + self.path + "'"
            out = getoutput(cmd)
            if verbose:
                print '# out', out

            if search('ASCII text', out):
                self.is_txt = True
                self.filetype = 'txt'

            if search('PDF document', out):
                self.is_pdf = True
                self.filetype = 'pdf'

            if search('OpenDocument Text', out):
                self.is_odt = True
                self.filetype = 'odt'

            if search('CDF V2 Document', out):
                self.is_doc = True
                self.filetype = 'doc'

            if self.filetype == '':  # if still ''
                self.filetype = 'empty'
                self.is_empty = True

        if verbose:
            print '\t#filetype: ', self.filetype


def option_parser():
    """
    This shows and gets options.
    """
    description = ''
    version = __version__
    usage = '%prog <options> word word word word'
    parser = OptionParser(description=description,
                              version=version,
                              usage=usage)
    parser.add_option("-u", "--update_db", dest="update_db",
                      default=False, help="force to update databases",
                      action="store_true")
    parser.add_option("-l", "--not_less", dest="not_less",
                      default=False, help="not_less, print extra lines",
                      action="store_true")
    parser.add_option("-g", "--global_search", dest="global_search",
                      default=False, help="search globally all PLACES",
                      action="store_true")
    parser.add_option("-d", "--find_dir", dest="find_dir",
                      default=False, help="search only for directories",
                      action="store_true")
    parser.add_option("-f", "--find_find", dest="find_find",
                      default=False, help="search only local via find ~",
                      action="store_true")
    parser.add_option("-p", "--pdf_find", dest="pdf_find",
                      default=False, help="search only for PDFs",
                      action="store_true")
    parser.add_option("-s", "--show_hash", dest="show_hash",
                      default=False, help="show_hash",
                      action="store_true")
    parser.add_option("-o", "--document_find", dest="document_find",
                      default=False,
                      help="document_find (documents are odt, doc)",
                      action="store_true")
    parser.add_option("-t", "--find_tu", dest="find_tu",
                      default=False, help="find in a folder",
                      action="store_true")
    parser.add_option("-e", "--dev", dest="dev",
                      default=False,
                      help="development version.. lots of prints",
                      action="store_true")
    parser.add_option("-k", "--key", dest="key",
                      default=False,
                      help="press key every place",
                      action="store_true")
    parser.add_option("-m", "--find_media", dest="find_media",
                      default=False,
                      help="find media (mp3, avi, mp4 and so on)",
                      action="store_true")
    parser.add_option("-r", "--rex", dest="rex",
                      default=False,
                      help="--regex '.*ods$'", action="store_true")
    parser.add_option("-x", "--un_grep", dest="un_grep",
                      default=False, help="--regex '.*ods$'",
                      action="store", type="string")
    parser.add_option("-w", "--wholename", dest="wholename",
                      default=False,
                      help="-w -match only the whole path " +
                      "name against the specified patterns",
                      action="store_true")
    parser.add_option("-b", "--bookmarks", dest="bookmarks",
                      default=False, help="-b search firefox bookmarks'",
                      action="store_true")
    parser.add_option("-y", "--bookmarks_folder", dest="bookmarks_folder",
                      default=False,
                      help="-y search firefox bookmark folders'",
                      action="store_true")
    parser.add_option("-v", "--verbose", dest="verbose",
                      default=False, help="-v verbose'",
                      action="store_true")
    parser.add_option("-i", "--invert", dest="invert",
                      default=False,
                      help="-i invert word1 word2 word3 --> word3 word2 word1",
                      action="store_true")
    parser.add_option("-c", "--grep_here", dest="grep_here",
                      default=False,
                      help="run grep search in the current folder",
                      action="store_true")
    parser.add_option("-n", "--noncolor", dest="noncolor",
                      default=False,
                      help="dont show colors, useful if you pipe an output",
                      action="store_true")
    parser.add_option("-a", "--www_browser", dest="www_browser",
                      default=False,
                      help="open an output in www browser",
                      action="store_true")

    (opt, arguments) = parser.parse_args()

    if not arguments:
        if not opt.update_db:
            parser.print_help()
            exit(1)
    if opt.update_db:
        print 'mmfinder_deamon start...'
        start_deamon()
        hr()
        print 'mmfinder_deamon [done]'
        sleep(2)

    if opt.dev:
        print '# opt', opt
    return arguments, opt




def start():
    """
    This runs the main program.
    """
    config = check_user_configuration()
    banner2('mmfinder.py')
    arguments, opt = option_parser()
    if arguments:
        m = App()
        m.search(arguments, opt)

if __name__ == "__main__":
    start()



#!/usr/bin/env python
#-*- coding: utf-8 -*-

import commands
import os
import imp
from os import path, sep, system
from getpass import getuser

LENGTH_OF_THE_SCREEN = 80
CHAR = "#"

def print_blue(text, newline = True):
    """
    http://www.siafoo.net/snippet/88
    """
    if newline:
        print '\033[1;34m' + text + '\033[1;m'
    else:
        print '\033[1;34m' + text + '\033[1;m',

def print_green(text, newline = True):
    """
    http://www.siafoo.net/snippet/88
    """
    if newline:
        print '\033[1;32m' + text + '\033[1;m'
    else:
        print '\033[1;32m' + text + '\033[1;m',

def print_red(text, newline = True):
    """
    http://www.siafoo.net/snippet/88
    """
    if newline:
        print '\033[1;31m' + text + '\033[1;m'
    else:
        print '\033[1;31m' + text + '\033[1;m',

def hr(len_of_hr = LENGTH_OF_THE_SCREEN,verbose=True):
    """
    GET:
    - len, by default it equals to LENGTH_OF_THE_SCREEN

    RETURNS:
    - string, like: -------------------------------------------------------
    """
    if verbose:
        st=CHAR * len_of_hr
        print st
        return True
    else:
        return False

def get_hostname(verbose = False):
    """

    In [4]: mmscikit.get_hostname()
    magnusbook
    Out[4]: 'magnusbook'

    """
    cmd = "hostname"
    out = commands.getoutput(cmd)
    if verbose: print out
    return out

def hr_text(text, len_of_hr = LENGTH_OF_THE_SCREEN,verbose=True):
    """
    GET:
    - len, by default it equals to LENGTH_OF_THE_SCREEN

    RETURNS:

    **********************************************************************
    # Job_id                                                        A1VY95
    ************************************************************** A1VY95 *
    """
    if verbose:
        text=str(text)
        st=CHAR * (len_of_hr - 3 - len(text)) + ' ' + text + ' ' + CHAR # 3 = ' 'test' '* = 2x' ' + 1x*
        print st
        return True
    else:
        return False

def get_datetime():
    """
    GET:
    - nothing
    RETURN:
    - string 2011-7-31 16:3
    """
    import time
    localtime = time.localtime(time.time())
    return '%d-%d-%d %d:%d'% localtime[:5]
def banner2(word):
    """
    Print banner via figlet
    """
    os.system('figlet ' + word)
def print_red_and_blue(text,text2, newline = True):
    """
    http://www.siafoo.net/snippet/88
    """
    if newline:
        print '\033[1;31m' + text + '\033[1;m' + '\033[1;34m' + text2 + '\033[1;m'
    else:
        print '\033[1;31m' + text + '\033[1;m' + '\033[1;34m' + text2 + '\033[1;m'


def check_user_configuration():
    """
    Simply checks the user configuration. Very, very rough!
    """
    user = getuser()
    path_to_config = '/home/' + user + sep + '.mmfinder-config.py'
    if not path.exists(path_to_config):
        print ('Error: It looks that you don\'t have ~/.mmfinder-confg.py! See the example https://github.com/m4rx9/mmfinder/blob/master/mmfinder_config.py')
        while 1:
            yes_no = raw_input('Do you want to download the example and save it as ~/.mmfinder-config.py? [yes/no]: ')
            if yes_no == 'yes':
                    print 'wget https://github.com/m4rx9/mmfinder/blob/master/mmfinder_config.py -O ~/.mmfinder-config.py'
                    system('wget https://raw.github.com/m4rx9/mmfinder/master/mmfinder_config.py -O ~/.mmfinder-config.py')
                    break
            elif yes_no == 'no':
                break
            else:
                print 'Type yes or now'
                    
        exit(1)        
    config = imp.load_source('config', path_to_config)
    ## check if the db directory exists
    if not path.exists(config.PATH_DB):
        print ('Error: The folder for saving databases does not exists. Check ~/.mmfinder-confg.py PATH_DB variable!')
        exit(1)
    return config





#!/usr/bin/python
#-*-coding: utf-8 -*-
"""

a deamon for collecting data for mmfinder

not pretty.. full of quick-and-dirty hacks .. but works :-)

"""
__author__ = "Marcin Magnus"
__copyright__ = "Copyright 2010, Marcin Magnus"
__license__ = "GPL"
__maintainer__ = "Marcin Magnus"
__email__ = "mag_dex@o2.pl"
__status__ = "Development"
__version__ = '0.98 alpha'

import os
import commands
import os.path

import mmfinder_config as config

from lib.utils import banner2, hr, get_hostname, hr_text, print_red_and_blue, print_green, print_red, print_blue, get_datetime


class Database:
    """
    Class for database that collets data and print statistics.

    Basic usage:

    d = Database('/home/magnus/', '/home/magnus/Dropbox/db/netbook.db')
    d.scan()
    d.statistics()
    """
    def __init__(self, path_to_scan, filename_db):
        self.path_to_scan = path_to_scan
        self.filename_db = filename_db
        self.statistics = ''
        self.scan_done = False

    def scan(self):
        """
        Scans to for files. Prints output for operation:

        # PATH: /home/magnus/Dropbox
        # creating DB ...  /home/magnus/Dropbox/workspace/mmfinder/db/dropbox.db
        updatedb -l 0 -U '/home/magnus/Dropbox' -n 'Dropbox  Trash english-lingXwavsOnline backups-snapshots .libreoffice .dropbox.cache pubmex-all-pdfs-shit-test' -o '/home/magnus/Dropbox/workspace/mmfinder/db/dropbox.db'
        # done
        """
        if os.path.exists(self.path_to_scan):
            dont_db = ' '.join(config.DONT_DB)
            cmd = "updatedb -l 0 -U '" + self.path_to_scan + "' -n '" + dont_db + "' -o '" + self.filename_db + "'"
            print cmd
            if config.RUN_UPDATE:
                os.system(cmd)
            print_green('# done')
            return True
        else:
            print_red('# ERROR: No such file or directory')
            return False

    def print_statistics(self):
        """
        Shows basic statistics, e.g.

        Database /home/magnus/Dropbox/workspace/mmfinder/db/dropbox.db:
        6,683 directories
        39,743 files
        3,434,386 bytes in file names
        1,456,819 bytes used to store database
        """
        cmd = "locate -S -d '" + self.filename_db + "'"
        out = commands.getoutput(cmd)
        hr()
        print out
        self.statistics = out
        hr()


def start():
    """
    Starts the main program.
    """
    hostname = get_hostname()
    locs = config.HOSTS[hostname]

    for l in locs:
        hr_text(l)
        path = locs[l]

        print_blue("# PATH: " + path)

        filename_db = config.PATH_DB + l + '.db'
        print "# creating DB ... ", filename_db

        dbf = Database(path, filename_db)
        if dbf.scan():
            dbf.print_statistics()

    # simply logging
    f = open(config.PATH_LOGFILE, 'aw')
    f.write(get_datetime() + '\n')
    f.close()

if __name__ == "__main__":
    start()



from setuptools import setup, find_packages
from os import system, path
from time import sleep

__version__ = "0.98 alpha"

print '*' * 80
print '*', 'Welcome!'
print '*', 'mmfinder ', __version__
print '*', 'run setup.py as a root!'
print '*' * 80

print 'figlet installing...'
system('sudo apt-get install figlet')
print
setup(
    # basic package data
    name = "mmfinder",
    author = "Marcin Magnus",
    description = 'a tool for finding your files across different machines',
    version = __version__,
    license = 'GPLv3',
    url = 'https://github.com/m4rx9/mmfinder',
    author_email = "mag_dex@o2.pl",
    packages = ['mmfinder','mmfinder.lib'],
    #long_description = read('README.md'),
    install_requires = ['pysqlite'],
    entry_points={
        'console_scripts': [
            'mmfinder = mmfinder.mmfinder:start',
            'mmfinder-deamon = mmfinder.mmfinder_deamon:start',
        ],
        }
)
print
print 'done :-) edit `~/.mmfinder-config.py` & run `mmfinder` to see what happens'



################################################################################
##                     BASIC (REQUIRED) CONFIGURATION                         ##
################################################################################
PATH_DB = '/home/magnus/Dropbox/data/mmfinder-db/'

## setup computers, ## name of db : path on that host'
computer1 = {
    'dropbox': '/home/magnus/Dropbox',
    'debian': '/home/magnus/',
    'StoreJet': '/media/StoreJet',
    '1TB': '/media/1TB',
    'StoreJet': '/media/StoreJet',
    }

computer2 = {
    'dropbox': '/home/magnus/Dropbox',
    'maximus': '/home/magnus/',
    'truecrypt': '/media/truecrypt1/',
    }

## map computer to hostname
HOSTS = {'debian': computer1, 'maximus': computer2}


################################################################################
##                     ADVANCED CONFIGURATION                                 ##
################################################################################

## list of disk
PLACES_LOCAL = ['dropbox']

databases_of_computers = [h.keys() for h in HOSTS.values()]
global_places = []
for db in databases_of_computers:
    for i in db:
        if i not in global_places:
            global_places.append(i)
PLACES_GLOBAL = global_places


DONT_DB = [
    'Dropbox',
    ' Trash',
    'english-lingXwavsOnline',
    'backups-snapshots',
    '.libreoffice',
    '.dropbox.cache',
    'pubmex-all-pdfs-shit-test',
    ]

## firefox bookmarks (optional)
FF_SQLITE_DATABASE = '/home/magnus/.mozilla/firefox/ssfbppfu.default/places.sqlite'

## extensios of documents and media
EXTENSIONS_OF_DOCUMENTS = ['rtf', 'doc', 'odt', 'ppt', 'odp', 'ods', 'xls']
EXTENSIONS_OF_MEDIA = ['avi', 'mp4']

## html mode to present results
HTML_FN = '/tmp/a120c.html'
#HTML_CMD = '/usr/bin/firefox'
HTML_CMD = '/usr/bin/x-www-browser'

## logfile
PATH_LOGFILE = PATH_DB + '/log'

## grep cmd
GREP_CMD = 'grep -C 2 -r '  # -C 1

## run update, --mm but what for???
RUN_UPDATE = True
